#[repr(u8)]pub enum Icr27Irqc {
Show 16 variants
Irqc0 = 0,
Irqc1 = 1,
Irqc2 = 2,
Irqc3 = 3,
_RESERVED_4 = 4,
Irqc5 = 5,
Irqc6 = 6,
Irqc7 = 7,
Irqc8 = 8,
Irqc9 = 9,
Irqc10 = 10,
Irqc11 = 11,
Irqc12 = 12,
Irqc13 = 13,
Irqc14 = 14,
_RESERVED_f = 15,
}Variants
Irqc0 = 0
ISF is disabled.
Irqc1 = 1
ISF and DMA request on rising edge.
Irqc2 = 2
ISF and DMA request on falling edge.
Irqc3 = 3
ISF and DMA request on either edge.
_RESERVED_4 = 4
Irqc5 = 5
ISF sets on rising edge.
Irqc6 = 6
ISF sets on falling edge.
Irqc7 = 7
ISF sets on either edge.
Irqc8 = 8
ISF and interrupt when logic 0.
Irqc9 = 9
ISF and interrupt on rising edge.
Irqc10 = 10
ISF and interrupt on falling edge.
Irqc11 = 11
ISF and Interrupt on either edge.
Irqc12 = 12
ISF and interrupt when logic 1.
Irqc13 = 13
Enable active-high trigger output; ISF on rising edge (pin state is ORed with other enabled triggers to generate the output trigger for use by other peripherals).
Irqc14 = 14
Enable active-low trigger output; ISF on falling edge (pin state is inverted and ORed with other enabled triggers to generate the output trigger for use by other peripherals).
_RESERVED_f = 15
Implementations